<!DOCTYPE TS><TS>
<context>
    <name>AdvSearch</name>
    <message>
        <source>All clauses</source>
        <translation>Toutes les clauses</translation>
    </message>
    <message>
        <source>Any clause</source>
        <translation>Une des clauses</translation>
    </message>
    <message>
        <source>texts</source>
        <translation>textes</translation>
    </message>
    <message>
        <source>spreadsheets</source>
        <translation>feuilles de calcul</translation>
    </message>
    <message>
        <source>presentations</source>
        <translation>présentations</translation>
    </message>
    <message>
        <source>media</source>
        <translation>multimédia</translation>
    </message>
    <message>
        <source>messages</source>
        <translation>messages</translation>
    </message>
    <message>
        <source>other</source>
        <translation>autres</translation>
    </message>
</context>
<context>
    <name>AdvSearchBase</name>
    <message>
        <source>Advanced search</source>
        <translation>Recherche avancée</translation>
    </message>
    <message>
        <source>Restrict file types</source>
        <translation>Restreindre le type de fichier</translation>
    </message>
    <message>
        <source>Save as default</source>
        <translation>Sauver comme valeur initiale</translation>
    </message>
    <message>
        <source>Searched file types</source>
        <translation>Types de fichier recherchés</translation>
    </message>
    <message>
        <source>All ----&gt;</source>
        <translation>Tout ----&gt;</translation>
    </message>
    <message>
        <source>Sel -----&gt;</source>
        <translation>Sel -----&gt;</translation>
    </message>
    <message>
        <source>&lt;----- Sel</source>
        <translation>&lt;----- Sel</translation>
    </message>
    <message>
        <source>&lt;----- All</source>
        <translation>&lt;----- Tout</translation>
    </message>
    <message>
        <source>Ignored file types</source>
        <translation>Types de fichiers ignorés</translation>
    </message>
    <message>
        <source>Enter top directory for search</source>
        <translation>Entrer le répertoire où démarre la recherche</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Parcourir</translation>
    </message>
    <message>
        <source>Restrict results to files in subtree:</source>
        <translation>Restreindre les résultats aux fichiers de l&apos;arborescence:</translation>
    </message>
    <message>
        <source>Start Search</source>
        <translation>Lancer la recherche</translation>
    </message>
    <message>
        <source>Search for &lt;br&gt;documents&lt;br&gt;satisfying:</source>
        <translation>Rechercher les &lt;br&gt;documents&lt;br&gt;vérifiant:</translation>
    </message>
    <message>
        <source>Delete clause</source>
        <translation>Enlever une clause</translation>
    </message>
    <message>
        <source>Add clause</source>
        <translation>Ajouter une clause</translation>
    </message>
    <message>
        <source>Check this to enable filtering on file types</source>
        <translation>Cocher pour permettre le filtrage des types de fichiers</translation>
    </message>
    <message>
        <source>By categories</source>
        <translation>Par catégories</translation>
    </message>
    <message>
        <source>Check this to use file categories instead of raw mime types</source>
        <translation>Cocher pour utiliser les catégories de fichiers au lieu des types mimes</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
    <message>
        <source>All non empty fields on the right will be combined with AND (&quot;All clauses&quot; choice) or OR (&quot;Any clause&quot; choice) conjunctions. &lt;br&gt;&quot;Any&quot; &quot;All&quot; and &quot;None&quot; field types can accept a mix of simple words, and phrases enclosed in double quotes.&lt;br&gt;Fields with no data are ignored.</source>
        <translation>Tous les champs de droite non vides seront combinés par une conjonction ET (choix &quot;Toutes les clauses&quot;) ou OU (choix &quot;Une des clauses&quot;). &lt;br&gt; Les champs de type  &quot;Un de ces mots&quot;, &quot;Tous ces mots&quot; et &quot;Aucun de ces mots&quot; acceptent un mélange de mots et de phrases contenues dans des apostrophes &quot;une phrase&quot;.&lt;br&gt;Les champs non renseignés sont ignorés.</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>No db directory in configuration</source>
        <translation>Répertoire de la base de données non défini dans la configuration</translation>
    </message>
    <message>
        <source>Could not open database in </source>
        <translation>Impossible d&apos;ouvrir la base dans </translation>
    </message>
    <message>
        <source>.
Click Cancel if you want to edit the configuration file before indexing starts, or Ok to let it proceed.</source>
        <translation>Cliquer Annuler pour pouvoir éditer le fichier de configuration avant que l&apos;indexation ne démarre, ou Ok pour continuer.</translation>
    </message>
    <message>
        <source>Configuration problem (dynconf</source>
        <translation>Problème de configuration (dynconf)</translation>
    </message>
</context>
<context>
    <name>Preview</name>
    <message>
        <source>&amp;Search for:</source>
        <translation>&amp;Rechercher:</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation>&amp;Suivant</translation>
    </message>
    <message>
        <source>&amp;Previous</source>
        <translation>&amp;Precédent</translation>
    </message>
    <message>
        <source>Match &amp;Case</source>
        <translation>Respecter la &amp;casse</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Effacer</translation>
    </message>
    <message>
        <source>Creating preview text</source>
        <translation>Création du texte pour la prévisualisation</translation>
    </message>
    <message>
        <source>Loading preview text into editor</source>
        <translation>Chargement du texte de la prévisualisation</translation>
    </message>
    <message>
        <source>Cannot create temporary directory</source>
        <translation>Impossible de créer le répertoire temporaire</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Close Tab</source>
        <translation>Fermer l&apos;onglet</translation>
    </message>
    <message>
        <source>Missing helper program: </source>
        <translation>Programmes filtres externes manquants: </translation>
    </message>
    <message>
        <source>Can&apos;t turn doc into internal representation for </source>
        <translation>Impossible de traduire le document en représentation interne pour </translation>
    </message>
</context>
<context>
    <name>PreviewTextEdit</name>
    <message>
        <source>Show fields</source>
        <translation>Afficher les valeurs des champs</translation>
    </message>
    <message>
        <source>Show main text</source>
        <translation>Afficher le corps du texte</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimer</translation>
    </message>
    <message>
        <source>Print Current Preview</source>
        <translation>Imprimer la fenêtre de prévisualisation</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Global parameters</source>
        <translation>Paramètres globaux</translation>
    </message>
    <message>
        <source>Local parameters</source>
        <translation>Paramètres locaux</translation>
    </message>
    <message>
        <source>&lt;b&gt;Customised subtrees</source>
        <translation>&lt;b&gt;Répertoires avec paramètres spécifiques</translation>
    </message>
    <message>
        <source>The list of subdirectories in the indexed hierarchy &lt;br&gt;where some parameters need to be redefined. Default: empty.</source>
        <translation>La liste des sous-répertoires de la zone indexée&lt;br&gt;où certains paramètres sont redéfinis. Défaut: vide.</translation>
    </message>
    <message>
        <source>&lt;i&gt;The parameters that follow are set either at the top level, if nothing&lt;br&gt;or an empty line is selected in the listbox above, or for the selected subdirectory.&lt;br&gt;You can add or remove directories by clicking the +/- buttons.</source>
        <translation>&lt;i&gt;Les paramètres qui suivent sont définis soit globalement, si la sélection dans la liste ci-dessus&lt;br&gt;est vide ou réduite à la ligne vide, soit pour le répertoire sélectionné.&lt;br&gt;Vous pouvez ajouter et enlever des répertoires en cliquant les boutons +/-.</translation>
    </message>
    <message>
        <source>Skipped names</source>
        <translation>Noms ignorés</translation>
    </message>
    <message>
        <source>These are patterns for file or directory  names which should not be indexed.</source>
        <translation>Canevas définissant les fichiers ou répertoires qui ne doivent pas etre indexés.</translation>
    </message>
    <message>
        <source>Default character set</source>
        <translation>Jeu de caractères par défaut</translation>
    </message>
    <message>
        <source>This is the character set used for reading files which do not identify the character set internally, for example pure text files.&lt;br&gt;The default value is empty, and the value from the NLS environnement is used.</source>
        <translation>Jeu de caractères utilisé pour lire les fichiers qui ne l&apos;identifient pas de manière interne, par exemple les purs fichiers texte. &lt;br&gt;La valeur par défaut est vide, et le programme utilise l&apos;environnement.</translation>
    </message>
    <message>
        <source>Follow symbolic links</source>
        <translation>Suivre les liens symboliques</translation>
    </message>
    <message>
        <source>Follow symbolic links while indexing. The default is no, to avoid duplicate indexing</source>
        <translation>Indexer les fichiers et répertoires pointés par les liens symboliques. Pas fait par défaut pour éviter les indexations multiples</translation>
    </message>
    <message>
        <source>Index all file names</source>
        <translation>Indexer tous les noms de fichiers</translation>
    </message>
    <message>
        <source>Index the names of files for which the contents cannot be identified or processed (no or unsupported mime type). Default true</source>
        <translation>Indexer les noms des fichiers dont le contenu n&apos;est pas identifié ou traité (pas de type mime, ou type non supporté). Vrai par défaut</translation>
    </message>
    <message>
        <source>Beagle web history</source>
        <translation>Queue Beagle</translation>
    </message>
</context>
<context>
    <name>RclMain</name>
    <message>
        <source>About Recoll</source>
        <translation>À propos de Recoll</translation>
    </message>
    <message>
        <source>Executing: [</source>
        <translation>Exécution de: [</translation>
    </message>
    <message>
        <source>Cannot retrieve document info from database</source>
        <translation>Impossible d&apos;accéder au document dans la base</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Attention</translation>
    </message>
    <message>
        <source>Can&apos;t create preview window</source>
        <translation>Impossible de créer la fenêtre de visualisation</translation>
    </message>
    <message>
        <source>Query results</source>
        <translation>Résultats de la recherche</translation>
    </message>
    <message>
        <source>Document history</source>
        <translation>Historique des documents consultés</translation>
    </message>
    <message>
        <source>History data</source>
        <translation>Données d&apos;historique</translation>
    </message>
    <message>
        <source>Indexing in progress: </source>
        <translation>Indexation en cours: </translation>
    </message>
    <message>
        <source>Files</source>
        <translation>Fichiers</translation>
    </message>
    <message>
        <source>Purge</source>
        <translation>Nettoyage</translation>
    </message>
    <message>
        <source>Stemdb</source>
        <translation>Base radicaux</translation>
    </message>
    <message>
        <source>Closing</source>
        <translation>Fermeture</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Inconnue</translation>
    </message>
    <message>
        <source>This search is not active any more</source>
        <translation>Cette recherche n&apos;est plus active</translation>
    </message>
    <message>
        <source>Can&apos;t start query: </source>
        <translation>Impossible de démarrer la recherche:</translation>
    </message>
    <message>
        <source>Bad viewer command line for %1: [%2]
Please check the mimeconf file</source>
        <translation>Mauvaise commande pour %1: [%2]
Vérifier le fichier mimeconf</translation>
    </message>
    <message>
        <source>Cannot extract document or create temporary file</source>
        <translation>Impossible d&apos;extraire le document ou de créer le fichier temporaire</translation>
    </message>
    <message>
        <source>(no stemming)</source>
        <translation>(pas d&apos;expansion)</translation>
    </message>
    <message>
        <source>(all languages)</source>
        <translation>(tous les langages)</translation>
    </message>
    <message>
        <source>error retrieving stemming languages</source>
        <translation>impossible de trouver la liste des langages d&apos;expansion</translation>
    </message>
    <message>
        <source>Update &amp;Index</source>
        <translation>Mise à jour &amp;Index</translation>
    </message>
    <message>
        <source>Indexing interrupted</source>
        <translation>Indexation interrompue</translation>
    </message>
    <message>
        <source>Stop &amp;Indexing</source>
        <translation>Arrèter l&apos;&amp;Indexation</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Tout</translation>
    </message>
    <message>
        <source>media</source>
        <translation>multimédia</translation>
    </message>
    <message>
        <source>message</source>
        <translation>message</translation>
    </message>
    <message>
        <source>other</source>
        <translation>autres</translation>
    </message>
    <message>
        <source>presentation</source>
        <translation>présentation</translation>
    </message>
    <message>
        <source>spreadsheet</source>
        <translation>feuille de calcul</translation>
    </message>
    <message>
        <source>text</source>
        <translation>texte</translation>
    </message>
    <message>
        <source>sorted</source>
        <translation>trié</translation>
    </message>
    <message>
        <source>filtered</source>
        <translation>filtré</translation>
    </message>
    <message>
        <source>External applications/commands needed and not found for indexing your file types:

</source>
        <translation>Applications externes non trouvees pour indexer vos types de fichiers:

</translation>
    </message>
    <message>
        <source>No helpers found missing</source>
        <translation>Pas d&apos;applications manquantes</translation>
    </message>
    <message>
        <source>Missing helper programs</source>
        <translation>Applications manquantes</translation>
    </message>
    <message>
        <source>Save file dialog</source>
        <translation type="obsolete">Dialogue de sauvegarde de fichier</translation>
    </message>
    <message>
        <source>Choose a file name to save under</source>
        <translation type="obsolete">Choisir un nom pour le nouveau fichier</translation>
    </message>
    <message>
        <source>Document category filter</source>
        <translation>Filtre de catégories de documents</translation>
    </message>
    <message>
        <source>No external viewer configured for mime type [</source>
        <translation>Pas de visualiseur configuré pour le type MIME [</translation>
    </message>
    <message>
        <source>The viewer specified in mimeview for %1: %2 is not found.
Do you want to start the  preferences dialog ?</source>
        <translation>Le visualiseur spécifié dans mimeview pour %1: %2 est introuvable.
Voulez vous démarrer le dialogue de préférences ?</translation>
    </message>
    <message>
        <source>Can&apos;t access file: </source>
        <translation>Impossible d&apos;accéder au fichier: </translation>
    </message>
    <message>
        <source>Can&apos;t uncompress file: </source>
        <translation>Impossible de décomprimer le fichier: </translation>
    </message>
    <message>
        <source>Save file</source>
        <translation>Sauvegarder le fichier</translation>
    </message>
    <message>
        <source>Result count (est.)</source>
        <translation>Nombre de résultats (est.)</translation>
    </message>
    <message>
        <source>Query details</source>
        <translation>Détails de la recherche</translation>
    </message>
</context>
<context>
    <name>RclMainBase</name>
    <message>
        <source>Previous page</source>
        <translation>Page précédente</translation>
    </message>
    <message>
        <source>Next page</source>
        <translation>Page suivante</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fichier</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>&amp;Outils</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Aide</translation>
    </message>
    <message>
        <source>&amp;Preferences</source>
        <translation>&amp;Préférences</translation>
    </message>
    <message>
        <source>Search tools</source>
        <translation>Outils de recherche</translation>
    </message>
    <message>
        <source>Result list</source>
        <translation>Liste de résultats</translation>
    </message>
    <message>
        <source>&amp;About Recoll</source>
        <translation>&amp;A propos de Recoll</translation>
    </message>
    <message>
        <source>Document &amp;History</source>
        <translation>&amp;Historique des documents</translation>
    </message>
    <message>
        <source>Document  History</source>
        <translation>Historique des documents</translation>
    </message>
    <message>
        <source>&amp;Advanced Search</source>
        <translation>Recherche &amp;Avancée</translation>
    </message>
    <message>
        <source>Advanced/complex  Search</source>
        <translation>Recherche Avancée</translation>
    </message>
    <message>
        <source>&amp;Sort parameters</source>
        <translation>Paramètres pour le &amp;tri</translation>
    </message>
    <message>
        <source>Sort parameters</source>
        <translation>Paramètres pour le tri</translation>
    </message>
    <message>
        <source>Next page of results</source>
        <translation>Page suivante</translation>
    </message>
    <message>
        <source>Previous page of results</source>
        <translation>Page précédente</translation>
    </message>
    <message>
        <source>&amp;Query configuration</source>
        <translation>&amp;Recherche</translation>
    </message>
    <message>
        <source>&amp;User manual</source>
        <translation>&amp;Manuel</translation>
    </message>
    <message>
        <source>Recoll</source>
        <translation>Recoll</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Update &amp;index</source>
        <translation>&amp;Indexer</translation>
    </message>
    <message>
        <source>Term &amp;explorer</source>
        <translation>&amp;Exploration de l&apos;index</translation>
    </message>
    <message>
        <source>Term explorer tool</source>
        <translation>Outil d&apos;exploration de l&apos;index</translation>
    </message>
    <message>
        <source>External index dialog</source>
        <translation>Index externes</translation>
    </message>
    <message>
        <source>&amp;Erase document history</source>
        <translation>&amp;Effacer l&apos;historique des documents</translation>
    </message>
    <message>
        <source>First page</source>
        <translation>Premiere page</translation>
    </message>
    <message>
        <source>Go to first page of results</source>
        <translation>Aller a la premiere page de resultats</translation>
    </message>
    <message>
        <source>&amp;Indexing configuration</source>
        <translation>Configuration &amp;Indexation</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Tout</translation>
    </message>
    <message>
        <source>&amp;Show missing helpers</source>
        <translation>Afficher les application&amp;s manquantes</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <source>Shift+Home, Ctrl+S, Ctrl+Q, Ctrl+S</source>
        <translation type="obsolete">Shift+Home, Ctrl+S, Ctrl+Q, Ctrl+S</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Plein écran</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Shift+Home</source>
        <translation></translation>
    </message>
    <message>
        <source>Full Screen</source>
        <translation>Plein écran</translation>
    </message>
    <message>
        <source>&amp;Erase search history</source>
        <translation>&amp;Effacer l&apos;historique des recherches</translation>
    </message>
    <message>
        <source>sortByDateAsc</source>
        <translation>sortByDateAsc</translation>
    </message>
    <message>
        <source>Sort by dates from oldest to newest</source>
        <translation>Trier par date des plus anciennes aux plus récentes</translation>
    </message>
    <message>
        <source>sortByDateDesc</source>
        <translation>sortByDateDesc</translation>
    </message>
    <message>
        <source>Sort by dates from newest to oldest</source>
        <translation>Trier par date des plus récentes aux plus anciennes</translation>
    </message>
    <message>
        <source>Show Query Details</source>
        <translation>Afficher la requête en détails</translation>
    </message>
    <message>
        <source>Show results as table</source>
        <translation>Afficher les résultats en tableau</translation>
    </message>
</context>
<context>
    <name>RecollModel</name>
    <message>
        <source>Abstract</source>
        <translation>Extrait</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Auteur</translation>
    </message>
    <message>
        <source>Document size</source>
        <translation>Taille document</translation>
    </message>
    <message>
        <source>Document date</source>
        <translation>Date document</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Taille fichier</translation>
    </message>
    <message>
        <source>File name</source>
        <translation>Nom de fichier</translation>
    </message>
    <message>
        <source>File date</source>
        <translation>Date fichier</translation>
    </message>
    <message>
        <source> Ipath</source>
        <translation>Ipath</translation>
    </message>
    <message>
        <source>Keywords</source>
        <translation>Mots clef</translation>
    </message>
    <message>
        <source>Mime type</source>
        <translation>Type Mime</translation>
    </message>
    <message>
        <source>Original character set</source>
        <translation>Jeu de caractères d&apos;origine</translation>
    </message>
    <message>
        <source>Relevancy rating</source>
        <translation>Pertinence</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titre</translation>
    </message>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Mtime</source>
        <translation>Mtime</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Date</translation>
    </message>
    <message>
        <source>Date and time</source>
        <translation>Date et heure</translation>
    </message>
</context>
<context>
    <name>ResList</name>
    <message>
        <source>Result list</source>
        <translation>Liste de résultats</translation>
    </message>
    <message>
        <source>Unavailable document</source>
        <translation>Document inaccessible</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Précédent</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Suivant</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;No results found&lt;/b&gt;&lt;br&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;Aucun résultat&lt;/b&gt;&lt;br&gt;</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>&amp;Voir contenu</translation>
    </message>
    <message>
        <source>Copy &amp;URL</source>
        <translation>Copier l&apos;&amp;Url</translation>
    </message>
    <message>
        <source>Find &amp;similar documents</source>
        <translation>Chercher des documents &amp;similaires</translation>
    </message>
    <message>
        <source>Query details</source>
        <translation type="obsolete">Détail de la recherche</translation>
    </message>
    <message>
        <source>(show query)</source>
        <translation>(requête)</translation>
    </message>
    <message>
        <source>Copy &amp;File Name</source>
        <translation>Copier le nom de &amp;Fichier</translation>
    </message>
    <message>
        <source>filtered</source>
        <translation type="obsolete">filtré</translation>
    </message>
    <message>
        <source>sorted</source>
        <translation type="obsolete">trié</translation>
    </message>
    <message>
        <source>Document history</source>
        <translation>Historique des documents consultés</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation>Prévisualisation</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Ouvrir</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;i&gt;Alternate spellings (accents suppressed): &lt;/i&gt;</source>
        <translation>&lt;p&gt;&lt;i&gt;Orthographes proposés (sans accents): &lt;/i&gt;</translation>
    </message>
    <message>
        <source>&amp;Write to File</source>
        <translation>&amp;Sauver sous</translation>
    </message>
    <message>
        <source>Preview P&amp;arent document/folder</source>
        <translation>Prévisualiser le document p&amp;arent</translation>
    </message>
    <message>
        <source>&amp;Open Parent document/folder</source>
        <translation>&amp;Ouvrir le document parent</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Ouvrir</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Documents</translation>
    </message>
    <message>
        <source>out of at least</source>
        <translation>parmi au moins</translation>
    </message>
    <message>
        <source>for</source>
        <translation>pour</translation>
    </message>
</context>
<context>
    <name>ResTable</name>
    <message>
        <source>&amp;Reset sort</source>
        <translation>&amp;Revenir au tri par pertinence</translation>
    </message>
    <message>
        <source>&amp;Delete column</source>
        <translation>&amp;Enlever la colonne</translation>
    </message>
    <message>
        <source>Add &quot;</source>
        <translation>Ajouter &quot;</translation>
    </message>
    <message>
        <source>&quot; column</source>
        <translation>&quot; colonne</translation>
    </message>
</context>
<context>
    <name>SSearch</name>
    <message>
        <source>Any term</source>
        <translation>Certains termes</translation>
    </message>
    <message>
        <source>All terms</source>
        <translation>Tous les termes</translation>
    </message>
    <message>
        <source>File name</source>
        <translation>Nom de fichier</translation>
    </message>
    <message>
        <source>Completions</source>
        <translation>Complétions</translation>
    </message>
    <message>
        <source>Select an item:</source>
        <translation>Sélectionner un élément:</translation>
    </message>
    <message>
        <source>Too many completions</source>
        <translation>Trop de complétions possibles</translation>
    </message>
    <message>
        <source>Query language</source>
        <translation>Language d&apos;interrogation</translation>
    </message>
    <message>
        <source>Bad query string</source>
        <translation>Requête non reconnue</translation>
    </message>
    <message>
        <source>Out of memory</source>
        <translation>Plus de mémoire disponible</translation>
    </message>
    <message>
        <source>Enter query language expression. Cheat sheet:&lt;br&gt;
&lt;i&gt;term1 term2&lt;/i&gt; : &apos;term1&apos; and &apos;term2&apos; in any field.&lt;br&gt;
&lt;i&gt;field:term1&lt;/i&gt; : &apos;term1&apos; in field &apos;field&apos;.&lt;br&gt;
 Standard field names/synonyms:&lt;br&gt;
  title/subject/caption, author/from, recipient/to, filename, ext.&lt;br&gt;
 Pseudo-fields: dir, mime/format, type/rclcat, date.&lt;br&gt;
 Two date interval exemples: 2009-03-01/2009-05-20  2009-03-01/P2M.&lt;br&gt;
&lt;i&gt;term1 term2 OR term3&lt;/i&gt; : term1 AND (term2 OR term3).&lt;br&gt;
  No actual parentheses allowed.&lt;br&gt;
&lt;i&gt;&quot;term1 term2&quot;&lt;/i&gt; : phrase (must occur exactly). Possible modifiers:&lt;br&gt;
&lt;i&gt;&quot;term1 term2&quot;p&lt;/i&gt; : unordered proximity search with default distance.&lt;br&gt;
Use &lt;b&gt;Show Query&lt;/b&gt; link when in doubt about result and see manual (&amp;lt;F1&gt;) for more detail.
</source>
        <translation>Entrer une expression du langage de recherche. Antisèche:&lt;br&gt;
&lt;i&gt;term1 term2&lt;/i&gt; : &apos;term1&apos; ET &apos;term2&apos; champ non spécifié.&lt;br&gt;
&lt;i&gt;field:term1&lt;/i&gt; : &apos;term1&apos; recherche dans le champ &apos;field&apos;.&lt;br&gt;
 Noms de champs standards (utiliser les mots anglais)/alias:&lt;br&gt;
  title/subject/caption, author/from, recipient/to, filename, ext.&lt;br&gt;
 Pseudo-champs: dir, mime/format, type/rclcat, date.&lt;br&gt;
 Examples d&apos;intervalles de dates: 2009-03-01/2009-05-20  2009-03-01/P2M.&lt;br&gt;
&lt;i&gt;term1 term2 OR term3&lt;/i&gt; : term1 AND (term2 OR term3).&lt;br&gt;
  NE PAS mettre les parenthèses.&lt;br&gt;
&lt;i&gt;&quot;term1 term2&quot;&lt;/i&gt; : phrase exacte. Options::&lt;br&gt;
&lt;i&gt;&quot;term1 term2&quot;p&lt;/i&gt; : proximité (pas d&apos;ordre).&lt;br&gt;
Utiliser le lien &lt;b&gt;Afficher la requête en détail&lt;/b&gt; en cas de doute sur les résultats et consulter le manuel (en anglais) (&amp;lt;F1&gt;) pour plus de détails.
</translation>
    </message>
    <message>
        <source>Enter file name wildcard expression.</source>
        <translation>Entrer un nom de fichier (caractères jokers possibles)</translation>
    </message>
    <message>
        <source>Enter search terms here. Type ESC SPC for completions of current term.</source>
        <translation>Entrer les termes recherchés ici. Taper ESC SPC pour afficher les mots commençant par l&apos;entrée en cours.</translation>
    </message>
</context>
<context>
    <name>SSearchBase</name>
    <message>
        <source>SSearchBase</source>
        <translation>SSearchBase</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Effacer</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <source>Erase search entry</source>
        <translation>Effacer l&apos;entrée</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Rechercher</translation>
    </message>
    <message>
        <source>Start query</source>
        <translation>Démarrer la recherche</translation>
    </message>
    <message>
        <source>Enter search terms here. Type ESC SPC for completions of current term.</source>
        <translation>Entrer les termes recherchés ici. Taper ESC SPC pour afficher les mots commençant par l&apos;entrée en cours.</translation>
    </message>
    <message>
        <source>Choose search type.</source>
        <translation>Choisir le type de recherche.</translation>
    </message>
</context>
<context>
    <name>SearchClauseW</name>
    <message>
        <source>SearchClauseW</source>
        <translation type="obsolete">SearchClauseW</translation>
    </message>
    <message>
        <source>Any of these</source>
        <translation>Un de ces mots</translation>
    </message>
    <message>
        <source>All of these</source>
        <translation>Tous ces mots</translation>
    </message>
    <message>
        <source>None of these</source>
        <translation>Aucun de ces mots</translation>
    </message>
    <message>
        <source>This phrase</source>
        <translation>Cette phrase</translation>
    </message>
    <message>
        <source>Terms in proximity</source>
        <translation>Termes en proximité</translation>
    </message>
    <message>
        <source>File name matching</source>
        <translation>Modèle de nom de fichier</translation>
    </message>
    <message>
        <source>Select the type of query that will be performed with the words</source>
        <translation>Sélectionner le type de requête à effectuer avec les mots</translation>
    </message>
    <message>
        <source>Number of additional words that may be interspersed with the chosen ones</source>
        <translation>Nombre de mots additionnels qui peuvent se trouver entre les termes recherchés</translation>
    </message>
</context>
<context>
    <name>SortForm</name>
    <message>
        <source>Date</source>
        <translation type="obsolete">Date</translation>
    </message>
    <message>
        <source>Mime type</source>
        <translation type="obsolete">Type Mime</translation>
    </message>
</context>
<context>
    <name>SortFormBase</name>
    <message>
        <source>Sort Criteria</source>
        <translation type="obsolete">Critères de tri</translation>
    </message>
    <message>
        <source>Sort the</source>
        <translation type="obsolete">Trier les</translation>
    </message>
    <message>
        <source>most relevant results by:</source>
        <translation type="obsolete">résultats les plus pertinents en fonction de:</translation>
    </message>
    <message>
        <source>Descending</source>
        <translation type="obsolete">Décroissant</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="obsolete">Fermer</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation type="obsolete">Appliquer</translation>
    </message>
</context>
<context>
    <name>SpellBase</name>
    <message>
        <source>Term Explorer</source>
        <translation>Explorateur d&apos;index</translation>
    </message>
    <message>
        <source>&amp;Expand </source>
        <translation>&amp;Dérivés</translation>
    </message>
    <message>
        <source>Alt+E</source>
        <translation>Alt+D</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Fermer</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation>Alt+F</translation>
    </message>
    <message>
        <source>Term</source>
        <translation type="obsolete">Terme</translation>
    </message>
    <message>
        <source>No db info.</source>
        <translation>Pas d&apos;information sur la base.</translation>
    </message>
    <message>
        <source>Doc. / Tot.</source>
        <translation type="obsolete">Doc. / Tot.</translation>
    </message>
</context>
<context>
    <name>SpellW</name>
    <message>
        <source>Wildcards</source>
        <translation>Wildcards</translation>
    </message>
    <message>
        <source>Regexp</source>
        <translation>Expression régulière</translation>
    </message>
    <message>
        <source>Spelling/Phonetic</source>
        <translation>Orthographe/Phonétique</translation>
    </message>
    <message>
        <source>Aspell init failed. Aspell not installed?</source>
        <translation>Erreur d&apos;initialisation aspell. Il n&apos;est peut-être pas installé?</translation>
    </message>
    <message>
        <source>Aspell expansion error. </source>
        <translation>Erreur aspell.</translation>
    </message>
    <message>
        <source>Stem expansion</source>
        <translation>Expansion grammaticale</translation>
    </message>
    <message>
        <source>error retrieving stemming languages</source>
        <translation>Impossible de former la liste des langages d&apos;expansion</translation>
    </message>
    <message>
        <source>No expansion found</source>
        <translation>Pas de résultats</translation>
    </message>
    <message>
        <source>Term</source>
        <translation>Terme</translation>
    </message>
    <message>
        <source>Doc. / Tot.</source>
        <translation>Doc. / Tot.</translation>
    </message>
    <message>
        <source>Index: %1 documents, average length %2 terms</source>
        <translation>Index: %1 documents, taille moyenne %2 termes</translation>
    </message>
</context>
<context>
    <name>UIPrefsDialog</name>
    <message>
        <source>The selected directory does not appear to be a Xapian index</source>
        <translation>Le répertoire sélectionné ne semble pas être un index Xapian</translation>
    </message>
    <message>
        <source>This is the main/local index!</source>
        <translation>C&apos;est l&apos;index principal !</translation>
    </message>
    <message>
        <source>The selected directory is already in the index list</source>
        <translation>Le répertoire sélectionné est déjà dans la liste</translation>
    </message>
    <message>
        <source>Select xapian index directory (ie: /home/buddy/.recoll/xapiandb)</source>
        <translation>Sélectionner un répertoire contenant un index Xapian (ex: /home/monAmi/.recoll/xapiandb)</translation>
    </message>
    <message>
        <source>error retrieving stemming languages</source>
        <translation>Impossible de former la liste des langues pour l&apos;expansion grammaticale</translation>
    </message>
</context>
<context>
    <name>UIPrefsDialogBase</name>
    <message>
        <source>User interface</source>
        <translation type="obsolete">Interface utilisateur</translation>
    </message>
    <message>
        <source>Number of entries in a result page</source>
        <translation type="obsolete">Nombre de résultats par page</translation>
    </message>
    <message>
        <source>Result list font</source>
        <translation type="obsolete">Fonte pour la liste de résultats</translation>
    </message>
    <message>
        <source>Helvetica-10</source>
        <translation type="obsolete">Helvetica-10</translation>
    </message>
    <message>
        <source>Opens a dialog to select the result list font</source>
        <translation type="obsolete">Ouvre une fenetre permettant de changer la fonte</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation type="obsolete">Réinitialiser</translation>
    </message>
    <message>
        <source>Resets the result list font to the system default</source>
        <translation type="obsolete">Réinitialiser la fonte à la valeur par défaut</translation>
    </message>
    <message>
        <source>Auto-start simple search on whitespace entry.</source>
        <translation type="obsolete">Démarrer automatiquement une recherche simple sur entrée d&apos;un espace.</translation>
    </message>
    <message>
        <source>Start with advanced search dialog open.</source>
        <translation type="obsolete">Panneau de recherche avancée ouvert au démarrage.</translation>
    </message>
    <message>
        <source>Start with sort dialog open.</source>
        <translation type="obsolete">Panneau de tri ouvert au démarrage.</translation>
    </message>
    <message>
        <source>Search parameters</source>
        <translation type="obsolete">Paramètres pour la recherche</translation>
    </message>
    <message>
        <source>Stemming language</source>
        <translation type="obsolete">Langue pour l&apos;expansion des termes</translation>
    </message>
    <message>
        <source>Dynamically build abstracts</source>
        <translation type="obsolete">Construire dynamiquement les résumés</translation>
    </message>
    <message>
        <source>Do we try to build abstracts for result list entries by using the context of query terms ? 
May be slow for big documents.</source>
        <translation type="obsolete">Décide si des résumés seront construits à partir du contexte des termes de recherche. 
Peut ralentir l&apos;affichage si les documents sont gros.</translation>
    </message>
    <message>
        <source>Replace abstracts from documents</source>
        <translation type="obsolete">Remplacer les résumés existant dans les documents</translation>
    </message>
    <message>
        <source>Do we synthetize an abstract even if the document seemed to have one?</source>
        <translation type="obsolete">Est-ce qu&apos;un résumé doit etre synthétisé meme dans le cas ou le document original en avait un?</translation>
    </message>
    <message>
        <source>Synthetic abstract size (characters)</source>
        <translation type="obsolete">Taille du résumé synthétique (caractères)</translation>
    </message>
    <message>
        <source>Synthetic abstract context words</source>
        <translation type="obsolete">Nombre de mots de contexte par occurrence de terme dans le résumé</translation>
    </message>
    <message>
        <source>External Indexes</source>
        <translation type="obsolete">Index externes</translation>
    </message>
    <message>
        <source>Add index</source>
        <translation type="obsolete">Ajouter un index</translation>
    </message>
    <message>
        <source>Select the xapiandb directory for the index you want to add, then click Add Index</source>
        <translation type="obsolete">Sélectionner le répertoire xapian de l&apos;index à ajouter, puis cliquer Ajouter Index</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation type="obsolete">Parcourir</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="obsolete">&amp;OK</translation>
    </message>
    <message>
        <source>Apply changes</source>
        <translation type="obsolete">Appliquer les modifications</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="obsolete">&amp;Annuler</translation>
    </message>
    <message>
        <source>Discard changes</source>
        <translation type="obsolete">Suivant</translation>
    </message>
    <message>
        <source>Result paragraph&lt;br&gt;format string</source>
        <translation type="obsolete">Chaîne de formatage&lt;br&gt;des paragraphes résultats</translation>
    </message>
    <message>
        <source>Automatically add phrase to simple searches</source>
        <translation type="obsolete">Ajouter automatiquement une phrase aux recherches simples</translation>
    </message>
    <message>
        <source>A search for [rolling stones] (2 terms) will be changed to [rolling or stones or (rolling phrase 2 stones)]. 
This should give higher precedence to the results where the search terms appear exactly as entered.</source>
        <translation type="obsolete">Une recherche pour [vin rouge] (2 mots) sera complétée comme [vin OU rouge OU (vin PHRASE 2 rouge)].&lt;br&gt;
Ceci devrait donner une meilleure pertinence aux résultats où les termes recherchés apparaissent exactement et dans l&apos;ordre.</translation>
    </message>
    <message>
        <source>User preferences</source>
        <translation type="obsolete">Préférences utilisateur</translation>
    </message>
    <message>
        <source>Use desktop preferences to choose document editor.</source>
        <translation type="obsolete">Utiliser les réglages du bureau pour choisir l&apos;application de visualisation.</translation>
    </message>
    <message>
        <source>External indexes</source>
        <translation type="obsolete">Index externes</translation>
    </message>
    <message>
        <source>Toggle selected</source>
        <translation type="obsolete">Changer l&apos;état pour les entrées sélectionnées</translation>
    </message>
    <message>
        <source>Activate All</source>
        <translation type="obsolete">Tout activer</translation>
    </message>
    <message>
        <source>Deactivate All</source>
        <translation type="obsolete">Tout désactiver</translation>
    </message>
    <message>
        <source>Remove selected</source>
        <translation type="obsolete">Effacer la sélection</translation>
    </message>
    <message>
        <source>Remove from list. This has no effect on the disk index.</source>
        <translation type="obsolete">Oter de la liste. Sans effet sur les données stockées.</translation>
    </message>
    <message>
        <source>Defines the format for each result list paragraph. Use qt html format and printf-like replacements:&lt;br&gt;%A Abstract&lt;br&gt; %D Date&lt;br&gt; %I Icon image name&lt;br&gt; %K Keywords (if any)&lt;br&gt; %L Preview and Edit links&lt;br&gt; %M Mime type&lt;br&gt; %N Result number&lt;br&gt; %R Relevance percentage&lt;br&gt; %S Size information&lt;br&gt; %T Title&lt;br&gt; %U Url&lt;br&gt;</source>
        <translation type="obsolete">Definit le format des paragraphes de la liste de resultats. Utilise le format html qt et des directives de substitution de type printf:&lt;br&gt;%A Abstract&lt;br&gt; %D Date&lt;br&gt; %I Icon image name&lt;br&gt; %K Keywords (if any)&lt;br&gt; %L Preview and Edit links&lt;br&gt; %M Mime type&lt;br&gt; %N Result number&lt;br&gt; %R Relevance percentage&lt;br&gt; %S Size information&lt;br&gt; %T Title&lt;br&gt; %U Url&lt;br&gt;</translation>
    </message>
    <message>
        <source>Remember sort activation state.</source>
        <translation type="obsolete">Memoriser l&apos;etat d&apos;activation du tri.</translation>
    </message>
    <message>
        <source>Maximum text size highlighted for preview (megabytes)</source>
        <translation type="obsolete">Taille maximum des textes surlignes avant previsualisation (MO)</translation>
    </message>
    <message>
        <source>Texts over this size will not be highlighted in preview (too slow).</source>
        <translation type="obsolete">Les texte plus gros ne seront pas surlignes dans la previsualisation (trop lent).</translation>
    </message>
    <message>
        <source>Highlight color for query terms</source>
        <translation type="obsolete">Couleur de mise en relief des termes recherchés</translation>
    </message>
    <message>
        <source>Prefer Html to plain text for preview.</source>
        <translation type="obsolete">Utiliser le format Html pour la previsualisation.</translation>
    </message>
    <message>
        <source>If checked, results with the same content under different names will only be shown once.</source>
        <translation type="obsolete">N&apos;afficher qu&apos;une entrée pour les résultats de contenu identique.</translation>
    </message>
    <message>
        <source>Hide duplicate results.</source>
        <translation type="obsolete">Cacher les doublons.</translation>
    </message>
    <message>
        <source>Choose editor applications</source>
        <translation type="obsolete">Choisir les éditeurs pour les différents types de fichiers</translation>
    </message>
    <message>
        <source>Display category filter as toolbar instead of button panel (needs restart).</source>
        <translation type="obsolete">Afficher le filtre de catégorie comme une barre d&apos;outils plutot que comme un panneau de boutons (après le redémarrage).</translation>
    </message>
    <message>
        <source>The words in the list will be automatically turned to ext:xxx clauses in the query language entry.</source>
        <translation type="obsolete">Les mots de la liste seront automatiquement changés en clauses ext:xxx dans les requêtes en langage d&apos;interrogation.</translation>
    </message>
    <message>
        <source>Query language magic file name suffixes.</source>
        <translation type="obsolete">Suffixes automatiques pour le langage d&apos;interrogation.</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation type="obsolete">Activer</translation>
    </message>
</context>
<context>
    <name>ViewAction</name>
    <message>
        <source>Changing actions with different current values</source>
        <translation>Changement d&apos;actions avec des valeurs actuelles differentes</translation>
    </message>
    <message>
        <source>Mime type</source>
        <translation>Type Mime</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Commande</translation>
    </message>
</context>
<context>
    <name>ViewActionBase</name>
    <message>
        <source>File type</source>
        <translation type="obsolete">Type de fichier</translation>
    </message>
    <message>
        <source>Action</source>
        <translation type="obsolete">Action</translation>
    </message>
    <message>
        <source>Select one or several file types, then click Change Action to modify the program used to open them</source>
        <translation>Sélectionner une ou plusieurs types de fichiers, puis cliquer Changer pour modifier le programme utiliser pour les ouvrir</translation>
    </message>
    <message>
        <source>Change Action</source>
        <translation>Changer</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
    <message>
        <source>Native Viewers</source>
        <translation>Applications de visualisation</translation>
    </message>
    <message>
        <source>Select one or several mime types then click &quot;Change Action&quot;&lt;br&gt;You can also close this dialog and check &quot;Use desktop preferences&quot;&lt;br&gt;in the main panel to ignore this list and use your desktop defaults.</source>
        <translation>Sélectionner un ou plusieurs types MIME puis cliquer &quot;Modifier l&apos;Action&quot;&lt;br&gt;Vous pouvez aussi fermer ce dialogue et choisir &quot;Utiliser les préférences du bureau&quot;&lt;br&gt; dans le dialogue principal pour ignorer cette liste.</translation>
    </message>
</context>
<context>
    <name>confgui::ConfBeaglePanelW</name>
    <message>
        <source>Steal Beagle indexing queue</source>
        <translation>Voler la queue d&apos;indexation de Beagle</translation>
    </message>
    <message>
        <source>Beagle MUST NOT be running. Enables processing the beagle queue to index Firefox web history.&lt;br&gt;(you should also install the Firefox Beagle plugin)</source>
        <translation>Beagle NE DOIT PAS être actif. Permet de traiter la queue de Beagle pour indexer l&apos;historique des pages visitées de Firefox.&lt;br&gt; (Il faut aussi installer le plugin Beagle pour Firefox)</translation>
    </message>
    <message>
        <source>Web cache directory name</source>
        <translation>Nom du répertoire cache de pages WEB</translation>
    </message>
    <message>
        <source>The name for a directory where to store the cache for visited web pages.&lt;br&gt;A non-absolute path is taken relative to the configuration directory.</source>
        <translation>Le nom d&apos;un répertoire où stocker les copies des pages WEB visitées.&lt;br&gt;Le chemin peut être relatif au répertoire de configuration.</translation>
    </message>
    <message>
        <source>Max. size for the web cache (MB)</source>
        <translation>Taille maximum pour le cache (MB)</translation>
    </message>
    <message>
        <source>Entries will be recycled once the size is reached</source>
        <translation>Les pages seront écrasées quand la taille spécifiée est atteinte</translation>
    </message>
</context>
<context>
    <name>confgui::ConfIndexW</name>
    <message>
        <source>Can&apos;t write configuration file</source>
        <translation>Impossible d&apos;ecrire le fichier de configuration</translation>
    </message>
</context>
<context>
    <name>confgui::ConfParamFNW</name>
    <message>
        <source>Browse</source>
        <translation type="obsolete">Parcourir</translation>
    </message>
</context>
<context>
    <name>confgui::ConfParamSLW</name>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
</context>
<context>
    <name>confgui::ConfSubPanelW</name>
    <message>
        <source>Global</source>
        <translation>Global</translation>
    </message>
    <message>
        <source>Max. compressed file size (KB)</source>
        <translation>Taill maximale pour les fichiers à décomprimer (Ko)</translation>
    </message>
    <message>
        <source>This value sets a threshold beyond which compressedfiles will not be processed. Set to -1 for no limit, to 0 for no decompression ever.</source>
        <translation>Cette valeur définit un seuil au delà duquel les fichiers comprimés ne seront pas traités. Utiliser -1 pour désactiver la limitation, 0 pour ne traiter aucun fichier comprimé.</translation>
    </message>
    <message>
        <source>Max. text file size (MB)</source>
        <translation>Taille maximum d&apos;un fichier texte (MB)</translation>
    </message>
    <message>
        <source>This value sets a threshold beyond which text files will not be processed. Set to -1 for no limit. 
This is for excluding monster log files from the index.</source>
        <translation>Cette valeur est un seuil au delà duquel les fichiers texte ne seront pas indexés. Spécifier -1 pour supprimer la limite.
Utilisé pour éviter d&apos;indexer des fichiers monstres.</translation>
    </message>
    <message>
        <source>Text file page size (KB)</source>
        <translation>Taille de découpe pour les fichiers texte (KB)</translation>
    </message>
    <message>
        <source>If this value is set (not equal to -1), text files will be split in chunks of this size for indexing.
This will help searching very big text  files (ie: log files).</source>
        <translation>Si cette valeur est spécifiée et positive, les fichiers texte seront découpés en tranches de cette taille pour l&apos;indexation.
Ceci diminue les ressources consommées par l&apos;indexation et aide le chargement pour prévisualisation.</translation>
    </message>
    <message>
        <source>Max. filter exec. time (S)</source>
        <translation>Temps d&apos;exécution maximum pour un filtre (S)</translation>
    </message>
    <message>
        <source>External filters working longer than this will be aborted. This is for the rare case (ie: postscript) where a document could cause a filter to loopSet to -1 for no limit.
</source>
        <translation>Un filtre externe sera interrompu si l&apos;attente dépasse ce temps. Utile dans le cas rare (programme postscript par exemple) où un document pourrait forcer un filtre à boucler indéfiniment. Positionner à -1 pour supprimer la limite.</translation>
    </message>
</context>
<context>
    <name>confgui::ConfTopPanelW</name>
    <message>
        <source>Top directories</source>
        <translation>Repertoires de depart</translation>
    </message>
    <message>
        <source>The list of directories where recursive indexing starts. Default: your home.</source>
        <translation>La liste des repertoires ou l&apos;indexation recursive demarre. Default: votre repertoire par defaut.</translation>
    </message>
    <message>
        <source>Skipped paths</source>
        <translation>Chemins ignores</translation>
    </message>
    <message>
        <source>These are names of directories which indexing will not enter.&lt;br&gt; May contain wildcards. Must match the paths seen by the indexer (ie: if topdirs includes &apos;/home/me&apos; and &apos;/home&apos; is actually a link to &apos;/usr/home&apos;, a correct skippedPath entry would be &apos;/home/me/tmp*&apos;, not &apos;/usr/home/me/tmp*&apos;)</source>
        <translation>Ce sont des noms de repertoires ou l&apos;indexation n&apos;entrera pas.&lt;br&gt;Ils peuvent contenir des caracteres jokers. Les chemins doivent correspondre a ceux vus par l&apos;indexeur (par exemple: si un des repertoires de depart est &apos;/home/me&apos; et que &apos;/home&apos; est un lien sur &apos;/usr/home&apos;, une entree correcte ici serait &apos;/home/me/tmp*&apos; , pas &apos;/usr/home/me/tmp*&apos;)</translation>
    </message>
    <message>
        <source>Stemming languages</source>
        <translation>Langue pour l&apos;expansion des termes</translation>
    </message>
    <message>
        <source>The languages for which stemming expansion&lt;br&gt;dictionaries will be built.</source>
        <translation>Les langages pour lesquels les dictionnaires d&apos;expansion&lt;br&gt;des termes  seront construits.</translation>
    </message>
    <message>
        <source>Log file name</source>
        <translation>Nom du fichier journal</translation>
    </message>
    <message>
        <source>The file where the messages will be written.&lt;br&gt;Use &apos;stderr&apos; for terminal output</source>
        <translation>Le nom du fichier ou les messages seront ecrits.&lt;br&gt;Utiliser &apos;stderr&apos; pour le terminal</translation>
    </message>
    <message>
        <source>Log verbosity level</source>
        <translation>Niveau de verbosite</translation>
    </message>
    <message>
        <source>This value adjusts the amount of messages,&lt;br&gt;from only errors to a lot of debugging data.</source>
        <translation>Cette valeur ajuste la quantite de messages emis,&lt;br&gt;depuis uniquement les erreurs jusqu&apos;a beaucoup de donnees de debug.</translation>
    </message>
    <message>
        <source>Index flush megabytes interval</source>
        <translation>Intervalle d&apos;ecriture de l&apos;index en megaoctets</translation>
    </message>
    <message>
        <source>This value adjust the amount of data which is indexed between flushes to disk.&lt;br&gt;This helps control the indexer memory usage. Default 10MB </source>
        <translation>Ajuste la quantite de donnees lues entre les ecritures sur disque.&lt;br&gt;Controle l&apos;utilisation de la memoire. Defaut 10 Mo </translation>
    </message>
    <message>
        <source>Max disk occupation (%)</source>
        <translation>Occupation disque maximum (%)</translation>
    </message>
    <message>
        <source>This is the percentage of disk occupation where indexing will fail and stop (to avoid filling up your disk).&lt;br&gt;0 means no limit (this is the default).</source>
        <translation>Niveau d&apos;occupation du disque ou l&apos;indexation s&apos;arrete (pour eviter un remplissage excessif).&lt;br&gt;0 signifie pas de limite (defaut).</translation>
    </message>
    <message>
        <source>No aspell usage</source>
        <translation>Pas d&apos;utilisation d&apos;aspell</translation>
    </message>
    <message>
        <source>Aspell language</source>
        <translation>Langue pour aspell</translation>
    </message>
    <message>
        <source>The language for the aspell dictionary. This should look like &apos;en&apos; or &apos;fr&apos; ...&lt;br&gt;If this value is not set, the NLS environment will be used to compute it, which usually works.To get an idea of what is installed on your system, type &apos;aspell config&apos; and look for .dat files inside the &apos;data-dir&apos; directory. </source>
        <translation>Langue du dictionnaire aspell. Une valeur correcte ressemble a &apos;en&apos; ou &apos;fr&apos;... &lt;br&gt;Si cette valeur n&apos;est pas positionnee, l&apos;environnement est utilise pour la calculer, ce qui marche bien, habituellement. Utiliser &apos;aspell config&apos; et regarder les fichiers .dat dans le repertoire &apos;data-dir&apos; pour connaitre les langues aspell installees sur votre systeme.</translation>
    </message>
    <message>
        <source>Database directory name</source>
        <translation>Repertoire de stockage de l&apos;index</translation>
    </message>
    <message>
        <source>The name for a directory where to store the index&lt;br&gt;A non-absolute path is taken relative to the  configuration directory. The default is &apos;xapiandb&apos;.</source>
        <translation>Le nom d&apos;un repertoire ou l&apos;index sera stocke&lt;br&gt;Un chemin relatif demarrera au repertoire de configuration. Le defaut est &apos;xapiandb&apos;.</translation>
    </message>
    <message>
        <source>Use system&apos;s &apos;file&apos; command</source>
        <translation>Utiliser la commande &apos;file&apos; du systeme</translation>
    </message>
    <message>
        <source>Use the system&apos;s &apos;file&apos; command if internal&lt;br&gt;mime type identification fails.</source>
        <translation>Utiliser la commande &apos;file&apos; si la determination&lt;br&gt;interne du type mime n&apos;obtient pas de resultat.</translation>
    </message>
    <message>
        <source>Disables use of aspell to generate spelling approximation in the term explorer tool.&lt;br&gt; Useful if aspell is absent or does not work. </source>
        <translation>Désactiver l&apos;utilisation d&apos;aspell pour générer les approximations orthographiques.&lt;br&gt; Utile si aspell n&apos;est pas installé ou ne fonctionne pas. </translation>
    </message>
</context>
<context>
    <name>uiPrefsDialogBase</name>
    <message>
        <source>User preferences</source>
        <translation>Préférences utilisateur</translation>
    </message>
    <message>
        <source>User interface</source>
        <translation>Interface utilisateur</translation>
    </message>
    <message>
        <source>Number of entries in a result page</source>
        <translation>Nombre de résultats par page</translation>
    </message>
    <message>
        <source>If checked, results with the same content under different names will only be shown once.</source>
        <translation>N&apos;afficher qu&apos;une entrée pour les résultats de contenu identique.</translation>
    </message>
    <message>
        <source>Hide duplicate results.</source>
        <translation>Cacher les doublons.</translation>
    </message>
    <message>
        <source>Highlight color for query terms</source>
        <translation>Couleur de mise en relief des termes recherchés</translation>
    </message>
    <message>
        <source>Result list font</source>
        <translation>Fonte pour la liste de résultats</translation>
    </message>
    <message>
        <source>Opens a dialog to select the result list font</source>
        <translation>Ouvre une fenêtre permettant de changer la fonte</translation>
    </message>
    <message>
        <source>Helvetica-10</source>
        <translation>Helvetica-10</translation>
    </message>
    <message>
        <source>Resets the result list font to the system default</source>
        <translation>Réinitialiser la fonte à la valeur par défaut</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Réinitialiser</translation>
    </message>
    <message>
        <source>Defines the format for each result list paragraph. Use qt html format and printf-like replacements:&lt;br&gt;%A Abstract&lt;br&gt; %D Date&lt;br&gt; %I Icon image name&lt;br&gt; %K Keywords (if any)&lt;br&gt; %L Preview and Edit links&lt;br&gt; %M Mime type&lt;br&gt; %N Result number&lt;br&gt; %R Relevance percentage&lt;br&gt; %S Size information&lt;br&gt; %T Title&lt;br&gt; %U Url&lt;br&gt;</source>
        <translation>Definit le format des paragraphes de la liste de resultats. Utilise le format html qt et des directives de substitution de type printf:&lt;br&gt;%A Abstract&lt;br&gt; %D Date&lt;br&gt; %I Icon image name&lt;br&gt; %K Keywords (if any)&lt;br&gt; %L Preview and Edit links&lt;br&gt; %M Mime type&lt;br&gt; %N Result number&lt;br&gt; %R Relevance percentage&lt;br&gt; %S Size information&lt;br&gt; %T Title&lt;br&gt; %U Url&lt;br&gt;</translation>
    </message>
    <message>
        <source>Result paragraph&lt;br&gt;format string</source>
        <translation>Chaîne de formatage&lt;br&gt;des paragraphes résultats</translation>
    </message>
    <message>
        <source>Texts over this size will not be highlighted in preview (too slow).</source>
        <translation>Les texte plus gros ne seront pas surlignés dans la prévisualisation (trop lent).</translation>
    </message>
    <message>
        <source>Maximum text size highlighted for preview (megabytes)</source>
        <translation>Taille maximum des textes surlignés avant prévisualisation (MO)</translation>
    </message>
    <message>
        <source>Use desktop preferences to choose document editor.</source>
        <translation>Utiliser les réglages du bureau pour choisir l&apos;application de visualisation.</translation>
    </message>
    <message>
        <source>Choose editor applications</source>
        <translation>Choisir les éditeurs pour les différents types de fichiers</translation>
    </message>
    <message>
        <source>Display category filter as toolbar instead of button panel (needs restart).</source>
        <translation>Afficher le filtre de catégorie comme une barre d&apos;outils plutot que comme un panneau de boutons (après le redémarrage).</translation>
    </message>
    <message>
        <source>Auto-start simple search on whitespace entry.</source>
        <translation>Démarrer automatiquement une recherche simple sur entrée d&apos;un espace.</translation>
    </message>
    <message>
        <source>Start with advanced search dialog open.</source>
        <translation>Panneau de recherche avancée ouvert au démarrage.</translation>
    </message>
    <message>
        <source>Start with sort dialog open.</source>
        <translation type="obsolete">Panneau de tri ouvert au démarrage.</translation>
    </message>
    <message>
        <source>Remember sort activation state.</source>
        <translation>Memoriser l&apos;etat d&apos;activation du tri.</translation>
    </message>
    <message>
        <source>Prefer Html to plain text for preview.</source>
        <translation>Utiliser le format Html pour la previsualisation.</translation>
    </message>
    <message>
        <source>Search parameters</source>
        <translation>Paramètres pour la recherche</translation>
    </message>
    <message>
        <source>Stemming language</source>
        <translation>Langue pour l&apos;expansion des termes</translation>
    </message>
    <message>
        <source>A search for [rolling stones] (2 terms) will be changed to [rolling or stones or (rolling phrase 2 stones)]. 
This should give higher precedence to the results where the search terms appear exactly as entered.</source>
        <translation>Une recherche pour [vin rouge] (2 mots) sera complétée comme [vin OU rouge OU (vin PHRASE 2 rouge)].&lt;br&gt;
Ceci devrait donner une meilleure pertinence aux résultats où les termes recherchés apparaissent exactement et dans l&apos;ordre.</translation>
    </message>
    <message>
        <source>Automatically add phrase to simple searches</source>
        <translation>Ajouter automatiquement une phrase aux recherches simples</translation>
    </message>
    <message>
        <source>Do we try to build abstracts for result list entries by using the context of query terms ? 
May be slow for big documents.</source>
        <translation>Décide si des résumés seront construits à partir du contexte des termes de recherche. 
Peut ralentir l&apos;affichage si les documents sont gros.</translation>
    </message>
    <message>
        <source>Dynamically build abstracts</source>
        <translation>Construire dynamiquement les résumés</translation>
    </message>
    <message>
        <source>Do we synthetize an abstract even if the document seemed to have one?</source>
        <translation>Est-ce qu&apos;un résumé doit etre synthétisé meme dans le cas ou le document original en avait un?</translation>
    </message>
    <message>
        <source>Replace abstracts from documents</source>
        <translation>Remplacer les résumés existant dans les documents</translation>
    </message>
    <message>
        <source>Synthetic abstract size (characters)</source>
        <translation>Taille du résumé synthétique (caractères)</translation>
    </message>
    <message>
        <source>Synthetic abstract context words</source>
        <translation>Nombre de mots de contexte par occurrence de terme dans le résumé</translation>
    </message>
    <message>
        <source>The words in the list will be automatically turned to ext:xxx clauses in the query language entry.</source>
        <translation>Les mots de la liste seront automatiquement changés en clauses ext:xxx dans les requêtes en langage d&apos;interrogation.</translation>
    </message>
    <message>
        <source>Query language magic file name suffixes.</source>
        <translation>Suffixes automatiques pour le langage d&apos;interrogation.</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Activer</translation>
    </message>
    <message>
        <source>External Indexes</source>
        <translation>Index externes</translation>
    </message>
    <message>
        <source>Toggle selected</source>
        <translation>Changer l&apos;état pour les entrées sélectionnées</translation>
    </message>
    <message>
        <source>Activate All</source>
        <translation>Tout activer</translation>
    </message>
    <message>
        <source>Deactivate All</source>
        <translation>Tout désactiver</translation>
    </message>
    <message>
        <source>Remove from list. This has no effect on the disk index.</source>
        <translation>Oter de la liste. Sans effet sur les données stockées.</translation>
    </message>
    <message>
        <source>Remove selected</source>
        <translation>Effacer la sélection</translation>
    </message>
    <message>
        <source>Click to add another index directory to the list</source>
        <translation>Cliquer pour ajouter un autre index à la liste</translation>
    </message>
    <message>
        <source>Add index</source>
        <translation>Ajouter un index</translation>
    </message>
    <message>
        <source>Apply changes</source>
        <translation>Appliquer les modifications</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Discard changes</source>
        <translation>Abandonner les modifications</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuler</translation>
    </message>
</context>
</TS>
